# Grad-Descent-Visualizer
A small package used to visualize test function landscapes and gradient descent.


<video src="https://user-images.githubusercontent.com/70919881/180077858-14bd8b91-c189-4e52-80d4-332ae5ca2db4.mov"></video>


## Install
```shell-session
pip install grad-descent-visualizer
```

## Usage
**Example 1:**
```python
from grad_descent_visualizer import DescentPlotter
```
